# BreathRate

Using cv2 to detect your movement and count your breath rate.


# Necessary Module
```python
 'pip install opencv-python '
 'pip install numpy '
 'pip install matplotlib '
 'pip install matplotlib '
 'pip install scipy '
 'pip install datetime '
```

# How to run

```python
 'pip install breathrate'
```
```python
 'import breathrate'
 'breathrate.breathrate()'
```